﻿<%@ Page Language="C#" AutoEventWireup="true" CodeBehind="Default.aspx.cs" Inherits="TaskSlip.Default" %>
<%@ Import Namespace="TaskSlip" %>

<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head runat="server">
    <title>TaskSlip.com</title>
    <link href="CSS/jquery-ui-1.8.4.custom.css" rel="stylesheet" type="text/css" />
    <link href="CSS/taskslip.css" rel="stylesheet" type="text/css" />

    <script src="Scripts/jquery-1.4.2.js" type="text/javascript"></script>
    <script src="Scripts/jquery-ui-1.8.4.custom.min.js" type="text/javascript"></script>
    <script type="text/javascript" src="Scripts/json2.min.js"></script>
    <!-- script type="text/javascript" src="Scripts/taskslip.js"></script -->
    <!-- following code should really go into above taskslip.js -->
    <script type="text/javascript">
        var sURL = unescape(window.location.pathname);

        function refreshPage() {
            setTimeout("refresh()", 1500);
        }

        function refresh() {
            window.location.href = sURL;
        }


        //setup defaults
        $.ajaxSetup({
            type: 'POST',
            contentType: 'application/json; charset=utf-8',
            dataType: 'json'
        });

        $(document).ready(function () {

            //Immediately hide the taskDialog.
            $('#taskDialog').hide();
            $('#showTaskDialog').show();

            $('#taskDialog').dialog({
                title: "Add Task",
                autoOpen: false,
                position: $('#showTaskDialog').position(),
                modal: true
            });

            $('#showTaskDialog').click(function (evt) {
                evt.preventDefault();

                $('#taskDialog').dialog('open');
                $('#Name').focus();
            });

            $('#Name').keypress(function (evt) {
                if (evt.keyCode == 13) {
                    evt.preventDefault(); //don't allow form to postback

                    //add the task
                    addTask();
                }
            });

            function addTask() {

                //Hide button
                $('#addTask').hide();

                //Store Task
                var dto = { name: $('#Name').val() };

                if ($.trim(dto.name) == '') {
                    $('#addTask').show();
                    return;
                }

                //Clear TextBox
                $('#Name').val('');

                //note if wanted to do a get for a html type then you could do type: 'get', contentType: 'html...
                $.ajax({
                    url: '/TaskService.asmx/AddTask',
                    data: JSON.stringify(dto),
                    success: function (response) {

                        var task = response.d; /*ASP.NET wraps JSON response in d for security reasons */
                        $('<li>', {
                            text: task.Name,
                            id: 'TaskID-' + task.Id
                        }).addClass('highlight')
                          .appendTo('#tasks')
                          .removeClass('highlight', 5000);
                    },
                    complete: function (response, status) {
                        $('#addTask').show(); //Show button again
                        $('#taskDialog').dialog("close");  //Close Dialog
                    }
                });

            }

            $('#addTask').click(function (evt) {
                evt.preventDefault();

                addTask();

            });

            $('#tasks').sortable({
                placeholder: 'ui-state-highlight',

                update: function (event, ui) {

                    $('#status').text('');

                    var dto = { 'taskIds': $(this).sortable('toArray') }

                    $.ajax({
                        data: JSON.stringify(dto),
                        url: '/TaskService.asmx/ReOrder',
                        success: function (response) {
                            var tasks = response.d;
                            if (tasks.success == false) {
                                $('#status').css('background-color', 'red').text(tasks.message + " - Reloading Page");

                                //It wasn't successful, so refresh the page so we can get the latest from the server
                                refreshPage();

                            }
                        }
                    });
                }
            });

            $('#tasks').delegate('li', 'click', function (evt) {

                //clear status
                $('#status').text('');

                var taskId = this.id.substring(7);
                var dto;

                if ($(this).hasClass('done')) {
                    dto = { 'id': taskId };

                    $.ajax({
                        url: '/TaskService.asmx/Delete',
                        data: JSON.stringify(dto),
                        success: $.proxy(function (result) {
                            if (result.d) {
                                $(this).fadeOut('slow', function () {
                                    $(this).remove();
                                });
                            }
                        }, this)
                    });
                }
                else {
                    $(this).addClass('completing');

                    dto = { 'id': taskId }

                    $.ajax({
                        url: '/TaskService.asmx/Complete',
                        data: JSON.stringify(dto),
                        success: $.proxy(function (result) {
                            var cr = result.d;
                            if (cr.success) {
                                $(this).addClass('done');
                            }
                            else {
                                $('#status').text(cr.message);
                            }
                        }, this),
                        complete: $.proxy(function (response, status) { $(this).removeClass('completing'); }, this)
                    });
                }
            });


        });

    </script>
</head>
<body>
    <form id="addTaskForm" runat="server">
    <div id="status"></div>
    <asp:Repeater runat="server" ID="taskList">
        <HeaderTemplate>
            <div class="header">Mind Your TaskSlip!</div>
            <ul id="tasks">
        </HeaderTemplate>
        <ItemTemplate>
            <li <%# ((bool)Eval("IsDone")) == true ? "class=done" : "" %> id='TaskID-<%# Eval("Id") %>'><%# Eval("Name") %></li>
        </ItemTemplate>
        <FooterTemplate>
            </ul></FooterTemplate>
    </asp:Repeater>
    <a href="#" id="showTaskDialog" style="display: none;">Add Task</a>
    <div id="taskDialog" >
        <asp:TextBox ID="Name" runat="server" />
        <asp:Button ID="addTask" runat="server" Text="Add" OnClick="addTask_Click" />
    </div>
    <div>
    </div>
    </form>
</body>
</html>
